==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appflow/kotlin/outputs/ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoData.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appflow.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property basicAuthCredentials The SAPOData basic authentication credentials.
 * @property oauthCredentials The SAPOData OAuth type authentication credentials.
 */
public data class ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoData(
    public val basicAuthCredentials:
    ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoDataBasicAuthCredentials? =
        null,
    public val oauthCredentials:
    ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoDataOauthCredentials? =
        null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appflow.outputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoData):
            ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoData =
            ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoData(
                basicAuthCredentials = javaType.basicAuthCredentials().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appflow.kotlin.outputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoDataBasicAuthCredentials.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                oauthCredentials = javaType.oauthCredentials().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appflow.kotlin.outputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoDataOauthCredentials.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appflow/kotlin/outputs/ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoData.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appflow.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property basicAuthCredentials The SAPOData basic authentication credentials.
 * @property oauthCredentials The SAPOData OAuth type authentication credentials.
 */
public data class ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoData(
    public val basicAuthCredentials: ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoDataBasicAuthCredentials? =
        null,
    public val oauthCredentials: ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoDataOauthCredentials? =
        null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appflow.outputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoData): ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoData =
            ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoData(
                basicAuthCredentials = javaType.basicAuthCredentials().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appflow.kotlin.outputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoDataBasicAuthCredentials.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                oauthCredentials = javaType.oauthCredentials().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appflow.kotlin.outputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsSapoDataOauthCredentials.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
